@@ -1,9 +1,9 @@
 try:
 	from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
-	from zcrmsdk.src.com.zoho.crm.api.util import Constants
+	from zcrmsdk.src.com.zoho.crm.api.util import Choice, Constants
 except Exception:
 	from ..exception import SDKException
-	from ..util import Constants
+	from ..util import Choice, Constants
 
 
 class Field(object):
@@ -14,9 +14,10 @@ class Field(object):
 		self.__webhook = None
 		self.__private = None
 		self.__layouts = None
+		self.__profiles = None
+		self.__sequence_number = None
 		self.__content = None
 		self.__column_name = None
-		self.__type = None
 		self.__transition_sequence = None
 		self.__personality_name = None
 		self.__message = None
@@ -30,6 +31,7 @@ class Field(object):
 		self.__created_source = None
 		self.__field_read_only = None
 		self.__display_label = None
+		self.__ui_type = None
 		self.__read_only = None
 		self.__association_details = None
 		self.__quick_sequence_number = None
@@ -39,25 +41,32 @@ class Field(object):
 		self.__id = None
 		self.__custom_field = None
 		self.__lookup = None
+		self.__filterable = None
 		self.__visible = None
+		self.__display_field = None
+		self.__pick_list_values_sorted_lexically = None
 		self.__length = None
 		self.__view_type = None
 		self.__subform = None
 		self.__api_name = None
+		self.__sortable = None
 		self.__unique = None
-		self.__history_tracking = None
 		self.__data_type = None
 		self.__formula = None
 		self.__decimal_place = None
 		self.__mass_update = None
 		self.__blueprint_supported = None
 		self.__multiselectlookup = None
+		self.__multiuserlookup = None
 		self.__pick_list_values = None
 		self.__auto_number = None
 		self.__default_value = None
-		self.__section_id = None
 		self.__validation_rule = None
 		self.__convert_mapping = None
+		self.__type = None
+		self.__external = None
+		self.__history_tracking = None
+		self.__display_type = None
 		self.__key_modified = dict()
 
 	def get_system_mandatory(self):
@@ -166,6 +175,54 @@ class Field(object):
 		self.__layouts = layouts
 		self.__key_modified['layouts'] = 1
 
+	def get_profiles(self):
+		"""
+		The method to get the profiles
+
+		Returns:
+			list: An instance of list
+		"""
+
+		return self.__profiles
+
+	def set_profiles(self, profiles):
+		"""
+		The method to set the value to profiles
+
+		Parameters:
+			profiles (list) : An instance of list
+		"""
+
+		if profiles is not None and not isinstance(profiles, list):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: profiles EXPECTED TYPE: list', None, None)
+		
+		self.__profiles = profiles
+		self.__key_modified['profiles'] = 1
+
+	def get_sequence_number(self):
+		"""
+		The method to get the sequence_number
+
+		Returns:
+			int: An int representing the sequence_number
+		"""
+
+		return self.__sequence_number
+
+	def set_sequence_number(self, sequence_number):
+		"""
+		The method to set the value to sequence_number
+
+		Parameters:
+			sequence_number (int) : An int representing the sequence_number
+		"""
+
+		if sequence_number is not None and not isinstance(sequence_number, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: sequence_number EXPECTED TYPE: int', None, None)
+		
+		self.__sequence_number = sequence_number
+		self.__key_modified['sequence_number'] = 1
+
 	def get_content(self):
 		"""
 		The method to get the content
@@ -214,30 +271,6 @@ class Field(object):
 		self.__column_name = column_name
 		self.__key_modified['column_name'] = 1
 
-	def get_type(self):
-		"""
-		The method to get the type
-
-		Returns:
-			string: A string representing the type
-		"""
-
-		return self.__type
-
-	def set_type(self, type):
-		"""
-		The method to set the value to type
-
-		Parameters:
-			type (string) : A string representing the type
-		"""
-
-		if type is not None and not isinstance(type, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: type EXPECTED TYPE: str', None, None)
-		
-		self.__type = type
-		self.__key_modified['_type'] = 1
-
 	def get_transition_sequence(self):
 		"""
 		The method to get the transition_sequence
@@ -570,6 +603,30 @@ class Field(object):
 		self.__display_label = display_label
 		self.__key_modified['display_label'] = 1
 
+	def get_ui_type(self):
+		"""
+		The method to get the ui_type
+
+		Returns:
+			int: An int representing the ui_type
+		"""
+
+		return self.__ui_type
+
+	def set_ui_type(self, ui_type):
+		"""
+		The method to set the value to ui_type
+
+		Parameters:
+			ui_type (int) : An int representing the ui_type
+		"""
+
+		if ui_type is not None and not isinstance(ui_type, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: ui_type EXPECTED TYPE: int', None, None)
+		
+		self.__ui_type = ui_type
+		self.__key_modified['ui_type'] = 1
+
 	def get_read_only(self):
 		"""
 		The method to get the read_only
@@ -676,7 +733,7 @@ class Field(object):
 		The method to get the multi_module_lookup
 
 		Returns:
-			dict: An instance of dict
+			MultiModuleLookup: An instance of MultiModuleLookup
 		"""
 
 		return self.__multi_module_lookup
@@ -686,11 +743,16 @@ class Field(object):
 		The method to set the value to multi_module_lookup
 
 		Parameters:
-			multi_module_lookup (dict) : An instance of dict
+			multi_module_lookup (MultiModuleLookup) : An instance of MultiModuleLookup
 		"""
 
-		if multi_module_lookup is not None and not isinstance(multi_module_lookup, dict):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: multi_module_lookup EXPECTED TYPE: dict', None, None)
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.fields.multi_module_lookup import MultiModuleLookup
+		except Exception:
+			from .multi_module_lookup import MultiModuleLookup
+
+		if multi_module_lookup is not None and not isinstance(multi_module_lookup, MultiModuleLookup):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: multi_module_lookup EXPECTED TYPE: MultiModuleLookup', None, None)
 		
 		self.__multi_module_lookup = multi_module_lookup
 		self.__key_modified['multi_module_lookup'] = 1
@@ -801,6 +863,30 @@ class Field(object):
 		self.__lookup = lookup
 		self.__key_modified['lookup'] = 1
 
+	def get_filterable(self):
+		"""
+		The method to get the filterable
+
+		Returns:
+			bool: A bool representing the filterable
+		"""
+
+		return self.__filterable
+
+	def set_filterable(self, filterable):
+		"""
+		The method to set the value to filterable
+
+		Parameters:
+			filterable (bool) : A bool representing the filterable
+		"""
+
+		if filterable is not None and not isinstance(filterable, bool):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: filterable EXPECTED TYPE: bool', None, None)
+		
+		self.__filterable = filterable
+		self.__key_modified['filterable'] = 1
+
 	def get_visible(self):
 		"""
 		The method to get the visible
@@ -825,6 +911,54 @@ class Field(object):
 		self.__visible = visible
 		self.__key_modified['visible'] = 1
 
+	def get_display_field(self):
+		"""
+		The method to get the display_field
+
+		Returns:
+			bool: A bool representing the display_field
+		"""
+
+		return self.__display_field
+
+	def set_display_field(self, display_field):
+		"""
+		The method to set the value to display_field
+
+		Parameters:
+			display_field (bool) : A bool representing the display_field
+		"""
+
+		if display_field is not None and not isinstance(display_field, bool):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: display_field EXPECTED TYPE: bool', None, None)
+		
+		self.__display_field = display_field
+		self.__key_modified['display_field'] = 1
+
+	def get_pick_list_values_sorted_lexically(self):
+		"""
+		The method to get the pick_list_values_sorted_lexically
+
+		Returns:
+			bool: A bool representing the pick_list_values_sorted_lexically
+		"""
+
+		return self.__pick_list_values_sorted_lexically
+
+	def set_pick_list_values_sorted_lexically(self, pick_list_values_sorted_lexically):
+		"""
+		The method to set the value to pick_list_values_sorted_lexically
+
+		Parameters:
+			pick_list_values_sorted_lexically (bool) : A bool representing the pick_list_values_sorted_lexically
+		"""
+
+		if pick_list_values_sorted_lexically is not None and not isinstance(pick_list_values_sorted_lexically, bool):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: pick_list_values_sorted_lexically EXPECTED TYPE: bool', None, None)
+		
+		self.__pick_list_values_sorted_lexically = pick_list_values_sorted_lexically
+		self.__key_modified['pick_list_values_sorted_lexically'] = 1
+
 	def get_length(self):
 		"""
 		The method to get the length
@@ -931,6 +1065,30 @@ class Field(object):
 		self.__api_name = api_name
 		self.__key_modified['api_name'] = 1
 
+	def get_sortable(self):
+		"""
+		The method to get the sortable
+
+		Returns:
+			bool: A bool representing the sortable
+		"""
+
+		return self.__sortable
+
+	def set_sortable(self, sortable):
+		"""
+		The method to set the value to sortable
+
+		Parameters:
+			sortable (bool) : A bool representing the sortable
+		"""
+
+		if sortable is not None and not isinstance(sortable, bool):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: sortable EXPECTED TYPE: bool', None, None)
+		
+		self.__sortable = sortable
+		self.__key_modified['sortable'] = 1
+
 	def get_unique(self):
 		"""
 		The method to get the unique
@@ -960,30 +1118,6 @@ class Field(object):
 		self.__unique = unique
 		self.__key_modified['unique'] = 1
 
-	def get_history_tracking(self):
-		"""
-		The method to get the history_tracking
-
-		Returns:
-			bool: A bool representing the history_tracking
-		"""
-
-		return self.__history_tracking
-
-	def set_history_tracking(self, history_tracking):
-		"""
-		The method to set the value to history_tracking
-
-		Parameters:
-			history_tracking (bool) : A bool representing the history_tracking
-		"""
-
-		if history_tracking is not None and not isinstance(history_tracking, bool):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: history_tracking EXPECTED TYPE: bool', None, None)
-		
-		self.__history_tracking = history_tracking
-		self.__key_modified['history_tracking'] = 1
-
 	def get_data_type(self):
 		"""
 		The method to get the data_type
@@ -1138,6 +1272,35 @@ class Field(object):
 		self.__multiselectlookup = multiselectlookup
 		self.__key_modified['multiselectlookup'] = 1
 
+	def get_multiuserlookup(self):
+		"""
+		The method to get the multiuserlookup
+
+		Returns:
+			MultiUserLookup: An instance of MultiUserLookup
+		"""
+
+		return self.__multiuserlookup
+
+	def set_multiuserlookup(self, multiuserlookup):
+		"""
+		The method to set the value to multiuserlookup
+
+		Parameters:
+			multiuserlookup (MultiUserLookup) : An instance of MultiUserLookup
+		"""
+
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.fields.multi_user_lookup import MultiUserLookup
+		except Exception:
+			from .multi_user_lookup import MultiUserLookup
+
+		if multiuserlookup is not None and not isinstance(multiuserlookup, MultiUserLookup):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: multiuserlookup EXPECTED TYPE: MultiUserLookup', None, None)
+		
+		self.__multiuserlookup = multiuserlookup
+		self.__key_modified['multiuserlookup'] = 1
+
 	def get_pick_list_values(self):
 		"""
 		The method to get the pick_list_values
@@ -1215,30 +1378,6 @@ class Field(object):
 		self.__default_value = default_value
 		self.__key_modified['default_value'] = 1
 
-	def get_section_id(self):
-		"""
-		The method to get the section_id
-
-		Returns:
-			int: An int representing the section_id
-		"""
-
-		return self.__section_id
-
-	def set_section_id(self, section_id):
-		"""
-		The method to set the value to section_id
-
-		Parameters:
-			section_id (int) : An int representing the section_id
-		"""
-
-		if section_id is not None and not isinstance(section_id, int):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: section_id EXPECTED TYPE: int', None, None)
-		
-		self.__section_id = section_id
-		self.__key_modified['section_id'] = 1
-
 	def get_validation_rule(self):
 		"""
 		The method to get the validation_rule
@@ -1287,6 +1426,112 @@ class Field(object):
 		self.__convert_mapping = convert_mapping
 		self.__key_modified['convert_mapping'] = 1
 
+	def get_type(self):
+		"""
+		The method to get the type
+
+		Returns:
+			string: A string representing the type
+		"""
+
+		return self.__type
+
+	def set_type(self, type):
+		"""
+		The method to set the value to type
+
+		Parameters:
+			type (string) : A string representing the type
+		"""
+
+		if type is not None and not isinstance(type, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: type EXPECTED TYPE: str', None, None)
+		
+		self.__type = type
+		self.__key_modified['type'] = 1
+
+	def get_external(self):
+		"""
+		The method to get the external
+
+		Returns:
+			External: An instance of External
+		"""
+
+		return self.__external
+
+	def set_external(self, external):
+		"""
+		The method to set the value to external
+
+		Parameters:
+			external (External) : An instance of External
+		"""
+
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.fields.external import External
+		except Exception:
+			from .external import External
+
+		if external is not None and not isinstance(external, External):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: external EXPECTED TYPE: External', None, None)
+		
+		self.__external = external
+		self.__key_modified['external'] = 1
+
+	def get_history_tracking(self):
+		"""
+		The method to get the history_tracking
+
+		Returns:
+			HistoryTracking: An instance of HistoryTracking
+		"""
+
+		return self.__history_tracking
+
+	def set_history_tracking(self, history_tracking):
+		"""
+		The method to set the value to history_tracking
+
+		Parameters:
+			history_tracking (HistoryTracking) : An instance of HistoryTracking
+		"""
+
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.fields.history_tracking import HistoryTracking
+		except Exception:
+			from .history_tracking import HistoryTracking
+
+		if history_tracking is not None and not isinstance(history_tracking, HistoryTracking):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: history_tracking EXPECTED TYPE: HistoryTracking', None, None)
+		
+		self.__history_tracking = history_tracking
+		self.__key_modified['history_tracking'] = 1
+
+	def get_display_type(self):
+		"""
+		The method to get the display_type
+
+		Returns:
+			Choice: An instance of Choice
+		"""
+
+		return self.__display_type
+
+	def set_display_type(self, display_type):
+		"""
+		The method to set the value to display_type
+
+		Parameters:
+			display_type (Choice) : An instance of Choice
+		"""
+
+		if display_type is not None and not isinstance(display_type, Choice):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: display_type EXPECTED TYPE: Choice', None, None)
+		
+		self.__display_type = display_type
+		self.__key_modified['display_type'] = 1
+
 	def is_key_modified(self, key):
 		"""
 		The method to check if the user has modified the given key
