@@ -50,7 +50,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
@@ -59,8 +59,8 @@ class RecordOperations(object):
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
 		handler_instance.set_param(param_instance)
 		handler_instance.set_header(header_instance)
-		Utility.get_fields(module_api_name)
 		handler_instance.set_module_api_name(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.response_handler import ResponseHandler
 		except Exception:
@@ -103,7 +103,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
@@ -113,8 +113,8 @@ class RecordOperations(object):
 		handler_instance.set_content_type('application/json')
 		handler_instance.set_request(request)
 		handler_instance.set_header(header_instance)
-		Utility.get_fields(module_api_name)
 		handler_instance.set_module_api_name(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
 		except Exception:
@@ -152,7 +152,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
@@ -161,6 +161,7 @@ class RecordOperations(object):
 		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
 		handler_instance.set_param(param_instance)
 		handler_instance.set_header(header_instance)
+		Utility.get_fields(module_api_name, handler_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
 		except Exception:
@@ -194,28 +195,29 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
 		handler_instance.set_param(param_instance)
 		handler_instance.set_header(header_instance)
-		Utility.get_fields(module_api_name)
 		handler_instance.set_module_api_name(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.response_handler import ResponseHandler
 		except Exception:
 			from .response_handler import ResponseHandler
 		return handler_instance.api_call(ResponseHandler.__module__, 'application/json')
 
-	def create_records(self, module_api_name, request):
+	def create_records(self, module_api_name, request, header_instance=None):
 		"""
 		The method to create records
 
 		Parameters:
 			module_api_name (string) : A string representing the module_api_name
 			request (BodyWrapper) : An instance of BodyWrapper
+			header_instance (HeaderMap) : An instance of HeaderMap
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -235,18 +237,21 @@ class RecordOperations(object):
 		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
+		if header_instance is not None and not isinstance(header_instance, HeaderMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
 		handler_instance.set_content_type('application/json')
 		handler_instance.set_request(request)
-		handler_instance.set_mandatory_checker(True)
-		Utility.get_fields(module_api_name)
+		handler_instance.set_header(header_instance)
 		handler_instance.set_module_api_name(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
 		except Exception:
@@ -285,17 +290,16 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
 		handler_instance.set_content_type('application/json')
 		handler_instance.set_request(request)
-		handler_instance.set_mandatory_checker(True)
 		handler_instance.set_header(header_instance)
-		Utility.get_fields(module_api_name)
 		handler_instance.set_module_api_name(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
 		except Exception:
@@ -329,13 +333,14 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
 		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
 		handler_instance.set_param(param_instance)
 		handler_instance.set_header(header_instance)
+		Utility.get_fields(module_api_name, handler_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
 		except Exception:
@@ -374,7 +379,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/upsert'
 		handler_instance.set_api_path(api_path)
@@ -383,8 +388,8 @@ class RecordOperations(object):
 		handler_instance.set_content_type('application/json')
 		handler_instance.set_request(request)
 		handler_instance.set_header(header_instance)
-		Utility.get_fields(module_api_name)
 		handler_instance.set_module_api_name(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
 		except Exception:
@@ -418,7 +423,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/deleted'
 		handler_instance.set_api_path(api_path)
@@ -426,6 +431,7 @@ class RecordOperations(object):
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
 		handler_instance.set_param(param_instance)
 		handler_instance.set_header(header_instance)
+		Utility.get_fields(module_api_name, handler_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.deleted_records_handler import DeletedRecordsHandler
 		except Exception:
@@ -459,7 +465,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/search'
 		handler_instance.set_api_path(api_path)
@@ -467,8 +473,8 @@ class RecordOperations(object):
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
 		handler_instance.set_param(param_instance)
 		handler_instance.set_header(header_instance)
-		Utility.get_fields(module_api_name)
 		handler_instance.set_module_api_name(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.response_handler import ResponseHandler
 		except Exception:
@@ -503,7 +509,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/Leads/'
+		api_path = api_path + '/crm/v2.1/Leads/'
 		api_path = api_path + str(id)
 		api_path = api_path + '/actions/convert'
 		handler_instance.set_api_path(api_path)
@@ -512,7 +518,7 @@ class RecordOperations(object):
 		handler_instance.set_content_type('application/json')
 		handler_instance.set_request(request)
 		handler_instance.set_mandatory_checker(True)
-		Utility.get_fields("Deals")
+		Utility.get_fields("Deals", handler_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.convert_action_handler import ConvertActionHandler
 		except Exception:
@@ -542,7 +548,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
@@ -550,6 +556,7 @@ class RecordOperations(object):
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
+		Utility.get_fields(module_api_name, handler_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.download_handler import DownloadHandler
 		except Exception:
@@ -588,7 +595,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
@@ -599,6 +606,7 @@ class RecordOperations(object):
 		handler_instance.set_content_type('multipart/form-data')
 		handler_instance.set_request(request)
 		handler_instance.set_mandatory_checker(True)
+		Utility.get_fields(module_api_name, handler_instance)
 		Utility.verify_photo_support(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.file_handler import FileHandler
@@ -629,7 +637,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
@@ -637,6 +645,7 @@ class RecordOperations(object):
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
 		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
+		Utility.get_fields(module_api_name, handler_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.file_handler import FileHandler
 		except Exception:
@@ -671,7 +680,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/actions/mass_update'
 		handler_instance.set_api_path(api_path)
@@ -680,8 +689,8 @@ class RecordOperations(object):
 		handler_instance.set_content_type('application/json')
 		handler_instance.set_request(request)
 		handler_instance.set_mandatory_checker(True)
-		Utility.get_fields(module_api_name)
 		handler_instance.set_module_api_name(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.mass_update_action_handler import MassUpdateActionHandler
 		except Exception:
@@ -711,19 +720,395 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/actions/mass_update'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
 		handler_instance.set_param(param_instance)
+		Utility.get_fields(module_api_name, handler_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.mass_update_response_handler import MassUpdateResponseHandler
 		except Exception:
 			from .mass_update_response_handler import MassUpdateResponseHandler
 		return handler_instance.api_call(MassUpdateResponseHandler.__module__, 'application/json')
 
+	def assign_territories_to_multiple_records(self, module_api_name, request):
+		"""
+		The method to assign territories to multiple records
+
+		Parameters:
+			module_api_name (string) : A string representing the module_api_name
+			request (BodyWrapper) : An instance of BodyWrapper
+
+		Returns:
+			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
+		"""
+
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.body_wrapper import BodyWrapper
+		except Exception:
+			from .body_wrapper import BodyWrapper
+
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
+		if request is not None and not isinstance(request, BodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		
+		handler_instance = CommonAPIHandler()
+		api_path = ''
+		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + str(module_api_name)
+		api_path = api_path + '/actions/assign_territories'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
+		handler_instance.set_module_api_name(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
+		except Exception:
+			from .action_handler import ActionHandler
+		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
+
+	def assign_territory_to_record(self, module_api_name, id, request):
+		"""
+		The method to assign territory to record
+
+		Parameters:
+			module_api_name (string) : A string representing the module_api_name
+			id (int) : An int representing the id
+			request (BodyWrapper) : An instance of BodyWrapper
+
+		Returns:
+			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
+		"""
+
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.body_wrapper import BodyWrapper
+		except Exception:
+			from .body_wrapper import BodyWrapper
+
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
+		if not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
+		
+		if request is not None and not isinstance(request, BodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		
+		handler_instance = CommonAPIHandler()
+		api_path = ''
+		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + str(module_api_name)
+		api_path = api_path + '/'
+		api_path = api_path + str(id)
+		api_path = api_path + '/actions/assign_territories'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_module_api_name(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
+		except Exception:
+			from .action_handler import ActionHandler
+		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
+
+	def remove_territories_from_multiple_records(self, module_api_name, request):
+		"""
+		The method to remove territories from multiple records
+
+		Parameters:
+			module_api_name (string) : A string representing the module_api_name
+			request (BodyWrapper) : An instance of BodyWrapper
+
+		Returns:
+			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
+		"""
+
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.body_wrapper import BodyWrapper
+		except Exception:
+			from .body_wrapper import BodyWrapper
+
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
+		if request is not None and not isinstance(request, BodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		
+		handler_instance = CommonAPIHandler()
+		api_path = ''
+		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + str(module_api_name)
+		api_path = api_path + '/actions/remove_territories'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
+		handler_instance.set_module_api_name(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
+		except Exception:
+			from .action_handler import ActionHandler
+		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
+
+	def remove_territories_from_record(self, module_api_name, id, request):
+		"""
+		The method to remove territories from record
+
+		Parameters:
+			module_api_name (string) : A string representing the module_api_name
+			id (int) : An int representing the id
+			request (BodyWrapper) : An instance of BodyWrapper
+
+		Returns:
+			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
+		"""
+
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.body_wrapper import BodyWrapper
+		except Exception:
+			from .body_wrapper import BodyWrapper
+
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
+		if not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
+		
+		if request is not None and not isinstance(request, BodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		
+		handler_instance = CommonAPIHandler()
+		api_path = ''
+		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + str(module_api_name)
+		api_path = api_path + '/'
+		api_path = api_path + str(id)
+		api_path = api_path + '/actions/remove_territories'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_module_api_name(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
+		except Exception:
+			from .action_handler import ActionHandler
+		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
+
+	def record_count(self, module_api_name, param_instance=None):
+		"""
+		The method to record count
+
+		Parameters:
+			module_api_name (string) : A string representing the module_api_name
+			param_instance (ParameterMap) : An instance of ParameterMap
+
+		Returns:
+			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
+		"""
+
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
+		if param_instance is not None and not isinstance(param_instance, ParameterMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
+		
+		handler_instance = CommonAPIHandler()
+		api_path = ''
+		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + str(module_api_name)
+		api_path = api_path + '/actions/count'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
+		handler_instance.set_param(param_instance)
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.count_handler import CountHandler
+		except Exception:
+			from .count_handler import CountHandler
+		return handler_instance.api_call(CountHandler.__module__, 'application/json')
+
+	def get_record_using_external_id(self, external_field_value, module_api_name, param_instance=None, header_instance=None):
+		"""
+		The method to get record using external id
+
+		Parameters:
+			external_field_value (string) : A string representing the external_field_value
+			module_api_name (string) : A string representing the module_api_name
+			param_instance (ParameterMap) : An instance of ParameterMap
+			header_instance (HeaderMap) : An instance of HeaderMap
+
+		Returns:
+			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
+		"""
+
+		if not isinstance(external_field_value, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: external_field_value EXPECTED TYPE: str', None, None)
+		
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
+		if param_instance is not None and not isinstance(param_instance, ParameterMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
+		
+		if header_instance is not None and not isinstance(header_instance, HeaderMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
+		
+		handler_instance = CommonAPIHandler()
+		api_path = ''
+		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + str(module_api_name)
+		api_path = api_path + '/'
+		api_path = api_path + str(external_field_value)
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
+		handler_instance.set_param(param_instance)
+		handler_instance.set_header(header_instance)
+		handler_instance.set_module_api_name(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.response_handler import ResponseHandler
+		except Exception:
+			from .response_handler import ResponseHandler
+		return handler_instance.api_call(ResponseHandler.__module__, 'application/json')
+
+	def update_record_using_external_id(self, external_field_value, module_api_name, request, header_instance=None):
+		"""
+		The method to update record using external id
+
+		Parameters:
+			external_field_value (string) : A string representing the external_field_value
+			module_api_name (string) : A string representing the module_api_name
+			request (BodyWrapper) : An instance of BodyWrapper
+			header_instance (HeaderMap) : An instance of HeaderMap
+
+		Returns:
+			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
+		"""
+
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.body_wrapper import BodyWrapper
+		except Exception:
+			from .body_wrapper import BodyWrapper
+
+		if not isinstance(external_field_value, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: external_field_value EXPECTED TYPE: str', None, None)
+		
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
+		if request is not None and not isinstance(request, BodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		
+		if header_instance is not None and not isinstance(header_instance, HeaderMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
+		
+		handler_instance = CommonAPIHandler()
+		api_path = ''
+		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + str(module_api_name)
+		api_path = api_path + '/'
+		api_path = api_path + str(external_field_value)
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_header(header_instance)
+		handler_instance.set_module_api_name(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
+		except Exception:
+			from .action_handler import ActionHandler
+		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
+
+	def delete_record_using_external_id(self, external_field_value, module_api_name, param_instance=None, header_instance=None):
+		"""
+		The method to delete record using external id
+
+		Parameters:
+			external_field_value (string) : A string representing the external_field_value
+			module_api_name (string) : A string representing the module_api_name
+			param_instance (ParameterMap) : An instance of ParameterMap
+			header_instance (HeaderMap) : An instance of HeaderMap
+
+		Returns:
+			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
+		"""
+
+		if not isinstance(external_field_value, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: external_field_value EXPECTED TYPE: str', None, None)
+		
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
+		if param_instance is not None and not isinstance(param_instance, ParameterMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
+		
+		if header_instance is not None and not isinstance(header_instance, HeaderMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
+		
+		handler_instance = CommonAPIHandler()
+		api_path = ''
+		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + str(module_api_name)
+		api_path = api_path + '/'
+		api_path = api_path + str(external_field_value)
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_param(param_instance)
+		handler_instance.set_header(header_instance)
+		Utility.get_fields(module_api_name, handler_instance)
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
+		except Exception:
+			from .action_handler import ActionHandler
+		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
+
 
 class GetRecordParam(object):
 	approved = Param('approved', 'com.zoho.crm.api.Record.GetRecordParam')
@@ -776,6 +1161,10 @@ class GetRecordsHeader(object):
 	x_external = Header('X-EXTERNAL', 'com.zoho.crm.api.Record.GetRecordsHeader')
 
 
+class CreateRecordsHeader(object):
+	x_external = Header('X-EXTERNAL', 'com.zoho.crm.api.Record.CreateRecordsHeader')
+
+
 class UpdateRecordsHeader(object):
 	x_external = Header('X-EXTERNAL', 'com.zoho.crm.api.Record.UpdateRecordsHeader')
 
@@ -812,6 +1201,7 @@ class SearchRecordsParam(object):
 	approved = Param('approved', 'com.zoho.crm.api.Record.SearchRecordsParam')
 	page = Param('page', 'com.zoho.crm.api.Record.SearchRecordsParam')
 	per_page = Param('per_page', 'com.zoho.crm.api.Record.SearchRecordsParam')
+	fields = Param('fields', 'com.zoho.crm.api.Record.SearchRecordsParam')
 
 
 class SearchRecordsHeader(object):
@@ -820,3 +1210,39 @@ class SearchRecordsHeader(object):
 
 class GetMassUpdateStatusParam(object):
 	job_id = Param('job_id', 'com.zoho.crm.api.Record.GetMassUpdateStatusParam')
+
+
+class RecordCountParam(object):
+	criteria = Param('criteria', 'com.zoho.crm.api.Record.RecordCountParam')
+	email = Param('email', 'com.zoho.crm.api.Record.RecordCountParam')
+	phone = Param('phone', 'com.zoho.crm.api.Record.RecordCountParam')
+	word = Param('word', 'com.zoho.crm.api.Record.RecordCountParam')
+
+
+class GetRecordUsingExternalIDParam(object):
+	approved = Param('approved', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDParam')
+	converted = Param('converted', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDParam')
+	cvid = Param('cvid', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDParam')
+	uid = Param('uid', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDParam')
+	fields = Param('fields', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDParam')
+	startdatetime = Param('startDateTime', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDParam')
+	enddatetime = Param('endDateTime', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDParam')
+	territory_id = Param('territory_id', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDParam')
+	include_child = Param('include_child', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDParam')
+
+
+class GetRecordUsingExternalIDHeader(object):
+	if_modified_since = Header('If-Modified-Since', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDHeader')
+	x_external = Header('X-EXTERNAL', 'com.zoho.crm.api.Record.GetRecordUsingExternalIDHeader')
+
+
+class UpdateRecordUsingExternalIDHeader(object):
+	x_external = Header('X-EXTERNAL', 'com.zoho.crm.api.Record.UpdateRecordUsingExternalIDHeader')
+
+
+class DeleteRecordUsingExternalIDParam(object):
+	wf_trigger = Param('wf_trigger', 'com.zoho.crm.api.Record.DeleteRecordUsingExternalIDParam')
+
+
+class DeleteRecordUsingExternalIDHeader(object):
+	x_external = Header('X-EXTERNAL', 'com.zoho.crm.api.Record.DeleteRecordUsingExternalIDHeader')
